ImageMetadata class

Metadata about an image found in the document.

Constructors

ImageMetadata({String? src, String? alt, String? title, int? width, int? height})
Creates a new ImageMetadata instance.
const
ImageMetadata.fromJson(Map<String, dynamic> json)
Creates an ImageMetadata instance from a JSON map.
factory

Properties

alt String?
The alternative text of the image.
final
hashCode int
The hash code for this object.
no setterinherited
height int?
The height of the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
The source URL of the image.
final
title String?
The title attribute of the image.
final
width int?
The width of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited