InlineImage class
Represents an inline image extracted from the HTML.
Constructors
-
InlineImage({required String dataBase64, required InlineImageFormat format, String? filename, String? description, int? width, int? height, required InlineImageSource source, Map<
String, String> attributes = const {}}) -
Creates a new InlineImage instance.
const
-
InlineImage.fromJson(Map<
String, dynamic> json) -
Creates an InlineImage instance from a JSON map.
factory
Properties
-
attributes
→ Map<
String, String> -
Additional attributes found on the image element.
final
- dataBase64 → String
-
Base64 encoded image data.
final
-
dataBytes
→ List<
int> -
The decoded bytes of the image data.
no setter
- description → String?
-
Optional description (alt text).
final
- filename → String?
-
Optional filename for the image.
final
- format → InlineImageFormat
-
Format of the image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Image height if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → InlineImageSource
-
Source of the image (data URI or SVG element).
final
- width → int?
-
Image width if available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited